ColumnType enum

Canonical column type — the backend normalizes its native type into one of these, and codegen maps it to a Dart type + SqlType.

Inheritance
Available extensions

Values

integer → const ColumnType
text → const ColumnType
real → const ColumnType
boolean → const ColumnType
blob → const ColumnType
dateTime → const ColumnType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ColumnType>
A constant List of the values in this enum, in order of their declaration.