DeleteStatement<Tbl> class final Insert, Update & Delete

DELETE FROM table WHERE ....

Inheritance
Available extensions

Constructors

DeleteStatement(String table)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table String
final
whereNode ↔ SqlNode?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
returning(List<TableColumn<Object?, Object?>> columns) Returning

Available on WriteStatement, provided by the WriteReturning extension

Return the given columns of the affected table after the write. Finish with .map(...) / .mapWith(...), then run via Connection.executeReturning:
toString() String
A string representation of this object.
inherited
where(Expression<bool, Tbl> predicate) DeleteStatement<Tbl>

Operators

operator ==(Object other) bool
The equality operator.
inherited