SqlType<T> class abstract base Types & Codecs

Inheritance
Implementers

Constructors

SqlType()
const

Properties

decoder Converter<Object?, T>
Returns the decoder of this, converting from T to S.
no setteroverride
encoder Converter<T, Object?>
Returns the encoder from S to T.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
inverted Codec<Object?, T>
Inverts this.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Object? encoded) → T
Decodes encoded data.
override
encode(T input) Object?
Encodes input.
override
fuse<R>(Codec<Object?, R> other) Codec<T, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited