ColumnDto class final

A table column in the transport model.

Constructors

ColumnDto({required String name, required String type, required String rawType, required bool isNullable, required bool isPrimaryKey, ForeignKeyDto? foreignKey})
const
ColumnDto.fromJson(Map<String, Object?> json)
factory

Properties

foreignKey ForeignKeyDto?
final
hashCode int
The hash code for this object.
no setterinherited
isNullable bool
final
isPrimaryKey bool
final
name String
final
rawType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Canonical ColumnType name (e.g. integer, text, dateTime).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited