ColumnFilter class final

One column predicate for InspectorService.getTableData.

op is one of eq / ne / lt / le / gt / ge / like / isNull / isNotNull. value is ignored for the null checks; for like it should be a string pattern (% wildcards). Combined with AND.

Constructors

ColumnFilter(String column, String op, [Object? value])
const
ColumnFilter.fromJson(Map json)
factory

Properties

column String
final
hashCode int
The hash code for this object.
no setterinherited
op String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited