ForeignKeyDto class final

A foreign-key target on a column.

Constructors

ForeignKeyDto(String table, String column)
const
ForeignKeyDto.fromJson(Map<String, Object?> json)
factory

Properties

column String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited