RegisteredInstance class final

Public description of a registered connection.

Constructors

RegisteredInstance({required String id, required String name})
const
RegisteredInstance.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Stable identifier assigned at registration (e.g. inst-0).
final
name String
Human-readable display label.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited