SqlResultDto class final
Result of InspectorService.runSql: a read (columns+rows), a write
(executed, optional affected count), or an error.
Constructors
- SqlResultDto.error(String? error)
-
const
-
SqlResultDto.fromJson(Map<
String, Object?> json) -
factory
-
SqlResultDto.read({required List<
String> ? columns, required List<List< ? rows, bool truncated = false})Object?> > -
const
- SqlResultDto.write({int? affected})
-
const
Properties
- affected → int?
-
final
-
columns
→ List<
String> ? -
final
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool
-
no setter
- isRead → bool
-
no setter
- kind → String
-
no setter
-
rows
→ List<
List< ?Object?> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- truncated → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited