TableDto class final

A table and its columns in the transport model.

Constructors

TableDto(String name, List<ColumnDto> columns)
const
TableDto.fromJson(Map<String, Object?> json)
factory

Properties

columns List<ColumnDto>
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited