TablePageDto class final

One page of table rows.

Constructors

TablePageDto({required List<String> columns, required List<List<Object?>> rows, required int total, required int limit, required int offset})
const
TablePageDto.fromJson(Map<String, Object?> json)
factory

Properties

columns List<String>
final
hashCode int
The hash code for this object.
no setterinherited
limit int
final
offset int
final
rows List<List<Object?>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited