Migration class final Schema Migrations
One migration: <version>_<name> with resolved up / optional down SQL.
Constructors
Properties
- down → String?
-
SQL applied by MigrationRunner.revertLast, or null when absent.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Human-readable suffix after the first
_.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- up → String
-
SQL applied by MigrationRunner.runPending.
final
- version → String
-
Ordering key — the directory-name prefix before the first
_.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited