DeleteStatement<Tbl> class
final
Insert, Update & Delete
DELETE FROM table WHERE ....
- Inheritance
-
- Object
- WriteStatement
- DeleteStatement
- Available extensions
Constructors
- DeleteStatement(String table)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
returning(
List< TableColumn< columns) → ReturningObject?, Object?> > -
Available on WriteStatement, provided by the WriteReturning extension
Return the given columns of the affected table after the write. Finish with.map(...)/.mapWith(...), then run viaConnection.executeReturning: -
toString(
) → String -
A string representation of this object.
inherited
-
where(
Expression< bool, Tbl> predicate) → DeleteStatement<Tbl>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited