RawSelection<T> class
final
Schema & Columns
A raw, typed SQL selection (escape hatch): emitted verbatim in the projection
and read back by its readKey (the raw as alias). Uses ? placeholders.
- Implemented types
-
- Selection<
T>
- Selection<
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- readKey → String
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectAlias → String?
-
no setteroverride
- selectExpression → SqlNode
-
no setteroverride
-
type
→ SqlType<
T> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited