ReturningQuery<R> class
final
Insert, Update & Delete
A write statement finished with a RETURNING projection and a row decoder —
the executable analog of MappedQuery for INSERT/UPDATE/DELETE.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
returning
→ List<
Projection> -
final
-
rowDecoder
→ R Function(List<
Object?> row) -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statement → WriteStatement
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited