SqlType<T> class
abstract
base
Types & Codecs
- Inheritance
- Implementers
Constructors
- SqlType()
-
const
Properties
-
decoder
→ Converter<
Object?, T> -
Returns the decoder of
this, converting fromTtoS.no setteroverride -
encoder
→ Converter<
T, Object?> -
Returns the encoder from
StoT.no setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
-
inverted
→ Codec<
Object?, T> -
Inverts
this.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
Object? encoded) → T -
Decodes
encodeddata.override -
encode(
T input) → Object? -
Encodes
input.override -
fuse<
R> (Codec< Object?, R> other) → Codec<T, R> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited